@@ -134,7 +134,7 @@ def password_change(request):
             return HttpResponseRedirect(reverse('auth_login') + '?next=%s' % request.path)
     
     if authkey:
-        required_old = False
+        require_old = False
         initial = {'authkey': authkey.id, 'uid': authkey.uid}
     else:
         require_old = True
